==> haskell-entropy-0.3.8-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-entropy.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: entropy
version: 0.3.8
id: entropy-0.3.8-Ka2swwibdrY798ueJnKpC0
key: entropy-0.3.8-Ka2swwibdrY798ueJnKpC0
license: BSD3
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
homepage: https://github.com/TomMD/entropy
synopsis: A platform independent entropy source
description:
    A platform independent method to obtain cryptographically strong entropy
    (RDRAND when available anywhere, urandom on nix, CryptAPI on Windows, patches welcome)
    Users looking for cryptographically strong (number-theoretically
    sound) PRNGs should see the '\''DRBG'\'' package too.
category: Data, Cryptography
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    System.Entropy
hidden-modules: System.EntropyNix
abi: a998ce1abfe528ef6b545a0f686f5cf7
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/entropy-0.3.8
library-dirs: /usr/lib/ghc-8.2.1/site-local/entropy-0.3.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/entropy-0.3.8
hs-libraries: HSentropy-0.3.8-Ka2swwibdrY798ueJnKpC0
depends:
    base-4.10.0.0 bytestring-0.10.8.2 unix-2.7.2.2
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
             unix-2.7.2.2=7af8630098b53e228272ffaea5bacf62
haddock-interfaces: /usr/share/doc/haskell-entropy/html/entropy.haddock
haddock-html: /usr/share/doc/haskell-entropy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-entropy-0.3.8-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-entropy.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: entropy
version: 0.3.8
id: entropy-0.3.8-459fr1KgYZzBPF08mWgtQU
key: entropy-0.3.8-459fr1KgYZzBPF08mWgtQU
license: BSD3
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
homepage: https://github.com/TomMD/entropy
synopsis: A platform independent entropy source
description:
    A platform independent method to obtain cryptographically strong entropy
    (RDRAND when available anywhere, urandom on nix, CryptAPI on Windows, patches welcome)
    Users looking for cryptographically strong (number-theoretically
    sound) PRNGs should see the '\''DRBG'\'' package too.
category: Data, Cryptography
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    System.Entropy
hidden-modules: System.EntropyNix
abi: 48b904d4ac32d9c7078ceefe10d1973a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/entropy-0.3.8
library-dirs: /usr/lib/ghc-8.2.2/site-local/entropy-0.3.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/entropy-0.3.8
hs-libraries: HSentropy-0.3.8-459fr1KgYZzBPF08mWgtQU
depends:
    base-4.10.1.0 bytestring-0.10.8.2 unix-2.7.2.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
haddock-interfaces: /usr/share/doc/haskell-entropy/html/entropy.haddock
haddock-html: /usr/share/doc/haskell-entropy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
